package com.woolha.hibernate.model;

import jakarta.persistence.Entity;
import jakarta.persistence.FetchType;
import jakarta.persistence.Id;
import jakarta.persistence.JoinColumn;
import jakarta.persistence.JoinTable;
import jakarta.persistence.ManyToMany;
import jakarta.persistence.OneToMany;
import jakarta.persistence.Table;
import java.util.List;
import java.util.UUID;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Getter;
import lombok.NoArgsConstructor;
import lombok.Setter;
import org.hibernate.annotations.UuidGenerator;
import org.hibernate.annotations.Where;
import org.hibernate.annotations.WhereJoinTable;

@AllArgsConstructor
@NoArgsConstructor
@Builder
@Getter
@Setter
@Entity
@Table(name = "categories")
@Where(clause = "is_deleted = false")
public class Category {

  @Id
  @UuidGenerator(style = UuidGenerator.Style.TIME)
  private UUID id;

  private String name;

  @Where(clause = "is_deleted = false")
  private Boolean isDeleted;

  @OneToMany(fetch = FetchType.LAZY)
  @JoinColumn(name = "category_id", referencedColumnName="id")
  @Where(clause = "is_active = true")
  private List<SubCategory> subCategories;

  @ManyToMany
  @JoinTable(name = "product_categories")
  @Where(clause = "is_shown = true")
  @WhereJoinTable(clause = "is_active = true")
  List<Product> products;
}
